/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { getString } from '@salesforce/ts-types';
import { ResultFormatter } from './resultFormatter.js';
export class DeployCancelResultFormatter extends ResultFormatter {
    result;
    constructor(ux, result) {
        super(ux);
        this.result = result;
    }
    getJson() {
        return this.result.response;
    }
    display() {
        const deployId = this.result.response.id;
        if (this.isSuccess()) {
            this.ux.log(`Successfully canceled ${deployId}`);
        }
        else {
            let errMsg = `Could not cancel ${deployId}`;
            const errMsgDueTo = getString(this.result, 'response.errorMessage');
            if (errMsgDueTo) {
                errMsg = `${errMsg} Due to: ${errMsgDueTo}`;
            }
            this.ux.warn(errMsg);
        }
    }
}
//# sourceMappingURL=deployCancelResultFormatter.js.map